ActorSystem class abstract

A system for managing actors.

The actor system is the entry point for creating and managing actors.

Implementers

Constructors

ActorSystem()

Properties

eventBus EventBus
The event bus of the actor system.
no setter
events Stream<EventBusEvent>
The events of the actor system.
no setter
hashCode int
The hash code for this object.
no setterinherited
logger → LogCollector
The log collector of the actor system.
no setter
metrics → MetricsCollector
The metrics collector of the actor system.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tracer → TraceCollector
The trace collector of the actor system.
no setter

Methods

getActor(String id) ActorRef?
Retrieves an actor by its ID.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shutdown() Future<void>
Shuts down the actor system.
spawn<T extends Actor>(String id, T actorFactory(), {SupervisionStrategy? supervision, Pool? pool}) Future<ActorRef>
Spawns a new actor.
stop(ActorRef actor) Future<void>
Stops the specified actor.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create([ActorSystemConfig? config]) ActorSystem
Creates a new actor system.