ActorSystemConfig class

The configuration for an actor system.

Constructors

ActorSystemConfig({MetricsCollector? metricsCollector, TraceCollector? traceCollector, LogCollector? logCollector, AskConfig? askConfig, int deadLetterQueueMaxSize = 1000})
ActorSystemConfig.development({MetricsCollector? metricsCollector, TraceCollector? traceCollector, LogCollector? logCollector})
Creates a development-friendly configuration with longer timeouts and more retries.
factory
ActorSystemConfig.production({MetricsCollector? metricsCollector, TraceCollector? traceCollector, LogCollector? logCollector})
Creates a production configuration with shorter timeouts and fewer retries.
factory

Properties

askConfig AskConfig
Configuration for ask pattern behavior including timeouts and retries.
final
deadLetterQueueMaxSize int
Maximum size of the dead letter queue before oldest entries are evicted.
final
hashCode int
The hash code for this object.
no setterinherited
logCollector → LogCollector?
final
metricsCollector → MetricsCollector?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
traceCollector → TraceCollector?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited